==> schorg-0.5.0-py2.py3-none-any.whl: schorg/SteeringPositionValue.py <==
"""
A value indicating a steering position.

https://schema.org/SteeringPositionValue
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class SteeringPositionValueInheritedProperties(TypedDict):
    """A value indicating a steering position.

    References:
        https://schema.org/SteeringPositionValue
    Note:
        Model Depth 5
    Attributes:
        greater: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is greater than the object.
        additionalProperty: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
        valueReference: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
        equal: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is equal to the object.
        lesser: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is lesser than the object.
        greaterOrEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
        lesserOrEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
        nonEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is not equal to the object.
    """

    greater: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    additionalProperty: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    valueReference: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    equal: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    lesser: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    greaterOrEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    lesserOrEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    nonEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class SteeringPositionValueProperties(TypedDict):
    """A value indicating a steering position.

    References:
        https://schema.org/SteeringPositionValue
    Note:
        Model Depth 5
    Attributes:
    """

    

#SteeringPositionValueInheritedPropertiesTd = SteeringPositionValueInheritedProperties()
#SteeringPositionValuePropertiesTd = SteeringPositionValueProperties()


class AllProperties(SteeringPositionValueInheritedProperties , SteeringPositionValueProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[SteeringPositionValueProperties, SteeringPositionValueInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "SteeringPositionValue"
    return model
    

SteeringPositionValue = create_schema_org_model()

==> schorg-0.7.0-py2.py3-none-any.whl: schorg/SteeringPositionValue.py <==
"""
A value indicating a steering position.

https://schema.org/SteeringPositionValue
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class SteeringPositionValueInheritedProperties(TypedDict):
    """A value indicating a steering position.

    References:
        https://schema.org/SteeringPositionValue
    Note:
        Model Depth 5
    Attributes:
        greater: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is greater than the object.
        additionalProperty: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
        valueReference: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A secondary value that provides additional information on the original value, e.g. a reference temperature or a type of measurement.
        equal: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is equal to the object.
        lesser: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is lesser than the object.
        greaterOrEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
        lesserOrEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
        nonEqual: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): This ordering relation for qualitative values indicates that the subject is not equal to the object.
    """

    greater: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    additionalProperty: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    valueReference: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    equal: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    lesser: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    greaterOrEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    lesserOrEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    nonEqual: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class SteeringPositionValueProperties(TypedDict):
    """A value indicating a steering position.

    References:
        https://schema.org/SteeringPositionValue
    Note:
        Model Depth 5
    Attributes:
    """

    


class AllProperties(SteeringPositionValueInheritedProperties , SteeringPositionValueProperties, TypedDict):
    pass


class SteeringPositionValueBaseModel(SchemaOrgBase):
    id_ : Optional[Any] = Field(default="SteeringPositionValue",alias='@id')
    context_ : Optional[Any] = Field(default=None,alias='@context')
    graph_ : Optional[Any] = Field(default=None,alias='@graph')

    class Config:
        
        fields = {'greater': {'exclude': True}}
        fields = {'additionalProperty': {'exclude': True}}
        fields = {'valueReference': {'exclude': True}}
        fields = {'equal': {'exclude': True}}
        fields = {'lesser': {'exclude': True}}
        fields = {'greaterOrEqual': {'exclude': True}}
        fields = {'lesserOrEqual': {'exclude': True}}
        fields = {'nonEqual': {'exclude': True}}
        


def create_schema_org_model(type_: Union[SteeringPositionValueProperties, SteeringPositionValueInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "SteeringPositionValue"
    return model
    

SteeringPositionValue = create_schema_org_model()


def create_steeringpositionvalue_model(model: AllProperties):
    _type =  AllProperties.copy()
    for k in model.keys():
        if k not in _type.__annotations__:
            del _type.__annotations__[k]
    return create_schema_org_model(type_=_type)


def schema_json(model: AllProperties):
    pydantic_type =  create_steeringpositionvalue_model(model=model)
    return pydantic_type(model).schema_json()
